package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````%",```````!``````````#@!`0``
M`````@```$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````*2>````````I)X`````````
M``$```````$````&````*/L````````H^P$``````"C[`0``````4`4`````
M``"X%0```````````0```````@````8```!(^P```````$C[`0``````2/L!
M``````#``0```````,`!````````"`````````!0Y71D!````"29````````
M))D````````DF0```````-P`````````W``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````H^P```````"C[`0``````*/L!``````#8!```````
M`-@$`````````0`````````O;&EB+VQD+6UU<VPM<&]W97)P8S8T;&4N<V\N
M,0```!$```!,````!`````@````@$!``!4`$@"@`$`2`A@"$@B$```D`!`F(
M@!A!N@0""`````!,````4````%0```!5````6P```%P```!=`````````%\`
M``!@`````````&$```!B````9```````````````:G^:?.K3[P[.WD<M;\7?
M'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'Q@&[XY)\
M5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IK&IY0H^#[20``````
M```````````````````````````````#``<`N!@`````````````````````
M```#``T`*/L!``````````````````P````28```````````````````````
M`+\!```28````````````````````````!0````1````````````````````
M`````.4!```1`````````````````````````&$!```28```````````````
M`````````!L````28````````````````````````)X!```28```````````
M`````````````",````28````````````````````````/(!```28```````
M`````````````````*H!```28````````````````````````"H````@````
M`````````````````````"8#```A`````````````````````````$(````2
M8````````````````````````$@````2`````````````````````````$\`
M```2`````````````````````````/,"```28```````````````````````
M`.0"```28````````````````````````'<"```28```````````````````
M`````%8````2`````````````````````````!@"```28```````````````
M`````````%T````28````````````````````````*P"```28```````````
M`````````````&0````28````````````````````````&P````2````````
M`````````````````)4"```28````````````````````````'0````28```
M`````````````````````'H````28````````````````````````(,````@
M`````````````````````````-T"```28````````````````````````)\`
M```28````````````````````````*0````28```````````````````````
M``,"```1`````````````````````````+,"```28```````````````````
M`````$4"```28````````````````````````*L````28```````````````
M`````````#<"```28````````````````````````$H#```28```````````
M`````````````"4#```1`````````````````````````&D"```28```````
M`````````````````!(#```28````````````````````````"<#```1````
M`````````````````````+(````28`````````````````````````H#```2
M8````````````````````````&\!```28````````````````````````+L`
M```B`````````````````````````,H````@````````````````````````
M`.`````28````````````````````````-4"```28```````````````````
M`````%4"```28````````````````````````.4````28```````````````
M`````````.L````@`````````````````````````*`"```28```````````
M``````````````4!```28````````````````````````(\!```28```````
M``````````````````H!```28````````````````````````(4"```28```
M`````````````````````'X!```28````````````````````````!`!```2
M`````````````````````````"$!```28````````````````````````!,"
M```28````````````````````````'4````28```````````````````````
M`"0"```28````````````````````````%X"```28```````````````````
M``````,#```28````````````````````````"<!```2````````````````
M`````````/L"```28````````````````````````#L!```2````````````
M``````````````X"```28````````````````````````,T!```28```````
M`````````````````$(!```2`````````````````````````$D!```2````
M`````````````````````"0#```A`````````````````````````%H!```2
M`````````````````````````!\#```28`@`H"````````!T`@```````-\!
M```28`D`K%L````````0`````````(P#```28`@`S#0````````@!P``````
M`#@$```28`@`V#\```````"8`````````&D#```28`@`K"T````````8````
M`````/8#```28`<`N!@````````0`````````*\#```28`@`[#L```````#L
M`P```````!P$```28`@`Q"T````````0`@```````.<#```0`!,`>``"````
M`````````````'H#```28`@`"#0```````#$`````````)D#```28`@`\"L`
M``````!D`````````*$#```28`@`,#,```````",`````````,4#```28`@`
MC%8```````!``0```````-H#```2``@`U"\````````X`````````#,$```0
M`!,`X!`"`````````````````"\#```28`@`0",```````!<`````````/P#
M```28`@`##````````!D`0```````-`#```1`!(`<``"```````(````````
M`!4$```0`!(`>``"`````````````````.P#```2``@`%",`````````````
M`````/,#```28`@`^%4```````"4`````````#@#```28`@`O#,```````!,
M`````````%,#```28`@`S"P```````#@`````````"D$```28`@`S%<`````
M``"D`0````````@$```28`@`<#$```````#``0````````!L:6)P97)L+G-O
M`&]P96YD:7(`<W1D97)R`')E86QL;V,`86-C97-S`%]?9&5R96=I<W1E<E]F
M<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M
M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7V-X
M85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S90!?
M251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S=')L
M96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`
M4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`&QI8F,N;75S;"UP<&,V-&QE+G-O+C$`9G!R:6YT
M9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<G1O
M:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`7W-T87)T
M7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?
M8G-S7W-T87)T`'-H85]I;FET`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?
M961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?96YD`'!A<E]C;&5A;G5P
M`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`````````````@``````
M%@````````````(``````!```@``````%@````````#86P```````!@``@``
M````%@`````````#7````````"@``@``````%@````````#=6P```````#``
M`@``````%@````````#=7````````#@``@``````%@````````#H6P``````
M`$```@``````%@````````#O7````````$@``@``````%@````````#P6P``
M`````%@``@``````%@````````#T6P```````&```@``````%@````````#Y
M6P```````'```@``````%@````````"17@````````C_`0``````)@```!X`
M`````````````!#_`0``````)@```#4``````````````!C_`0``````)@``
M`"\``````````````"#_`0``````)@````T``````````````"C_`0``````
M)@```#```````````````##_`0``````)@```"L``````````````#C_`0``
M````)@```"(``````````````$#_`0``````)@```#H``````````````$C_
M`0``````)@````4``````````````%#_`0``````)@```$``````````````
M`%C_`0``````)@```#L``````````````&#_`0``````)@````8`````````
M`````!C]`0``````%0````,``````````````"#]`0``````%0````0`````
M`````````"C]`0``````%0````<``````````````##]`0``````%0````@`
M`````````````#C]`0``````%0````D``````````````$#]`0``````%0``
M``H``````````````$C]`0``````%0````L``````````````%#]`0``````
M%0````P``````````````%C]`0``````%0````T``````````````&#]`0``
M````%0````\``````````````&C]`0``````%0```!```````````````'#]
M`0``````%0```!$``````````````'C]`0``````%0```!(`````````````
M`(#]`0``````%0```!,``````````````(C]`0``````%0```!0`````````
M`````)#]`0``````%0```!4``````````````)C]`0``````%0```!8`````
M`````````*#]`0``````%0```!<``````````````*C]`0``````%0```!@`
M`````````````+#]`0``````%0```!D``````````````+C]`0``````%0``
M`!H``````````````,#]`0``````%0```!L``````````````,C]`0``````
M%0```!P``````````````-#]`0``````%0```!T``````````````-C]`0``
M````%0```!\``````````````.#]`0``````%0```"```````````````.C]
M`0``````%0```"$``````````````/#]`0``````%0```",`````````````
M`/C]`0``````%0```"0```````````````#^`0``````%0```"4`````````
M``````C^`0``````%0```"8``````````````!#^`0``````%0```"<`````
M`````````!C^`0``````%0```"D``````````````"#^`0``````%0```"H`
M`````````````"C^`0``````%0```"P``````````````##^`0``````%0``
M`"T``````````````#C^`0``````%0```"X``````````````$#^`0``````
M%0```"\``````````````$C^`0``````%0```#```````````````%#^`0``
M````%0```#$``````````````%C^`0``````%0```#(``````````````&#^
M`0``````%0```#,``````````````&C^`0``````%0```#0`````````````
M`'#^`0``````%0```#8``````````````'C^`0``````%0```#<`````````
M`````(#^`0``````%0```#@``````````````(C^`0``````%0```#D`````
M`````````)#^`0``````%0```#P``````````````)C^`0``````%0```#T`
M`````````````*#^`0``````%0```#X``````````````*C^`0``````%0``
M`#\``````````````+#^`0``````%0```$$``````````````+C^`0``````
M%0```$(``````````````,#^`0``````%0```$,``````````````,C^`0``
M````%0```$0``````````````-#^`0``````%0```$4``````````````-C^
M`0``````%0```$8``````````````.#^`0``````%0```$<`````````````
M`.C^`0``````%0```$@``````````````/#^`0``````%0```$D`````````
M`````/C^`0``````%0```$L```````````````(`3#Q(9D(XI@((?!```?CA
M_R'XO0P`2````&"U0`!(````8"``(3@0``'HI@,(?"``@$X`````````````
M`````````````!@`0?C__X(]&'Z,Z:8#B7T@!(!.````````````````&`!!
M^/__@CTX?HSII@.)?2`$@$X````````````````8`$'X__^"/4A_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]\'Z,Z:8#B7T@!(!.````````````
M````&`!!^/__@CUH?HSII@.)?2`$@$X````````````````8`$'X__^"/:!^
MC.FF`XE](`2`3@```````````````!@`0?C__X(]J'^,Z:8#B7T@!(!.````
M````````````&`!!^/__@CV`?HSII@.)?2`$@$X````````````````8`$'X
M__^"/3!^C.FF`XE](`2`3@```````````````!@`0?C__X(]`'^,Z:8#B7T@
M!(!.````````````````&`!!^/__@CUP?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/=A_C.FF`XE](`2`3@```````````````!@`0?C__X(]B'^,
MZ:8#B7T@!(!.````````````````&`!!^/__@CT@?HSII@.)?2`$@$X`````
M```````````8`$'X__^"/5A^C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]F'^,Z:8#B7T@!(!.````````````````&`!!^/__@CW`?XSII@.)?2`$
M@$X````````````````8`$'X__^"/?!_C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]<'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CU(?HSI
MI@.)?2`$@$X````````````````8`$'X__^"/<A_C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]0'^,Z:8#B7T@!(!.````````````````&`!!^/__
M@CT8?XSII@.)?2`$@$X````````````````8`$'X__^"/0A_C.FF`XE](`2`
M3@```````````````!@`0?C__X(]*'Z,Z:8#B7T@!(!.````````````````
M&`!!^/__@CU0?HSII@.)?2`$@$X````````````````8`$'X__^"/9A^C.FF
M`XE](`2`3@```````````````!@`0?C__X(]>'Z,Z:8#B7T@!(!.````````
M````````&`!!^/__@CTX?XSII@.)?2`$@$X````````````````8`$'X__^"
M/>!_C.FF`XE](`2`3@```````````````!@`0?C__X(]H'^,Z:8#B7T@!(!.
M````````````````&`!!^/__@CVX?HSII@.)?2`$@$X````````````````8
M`$'X__^"/2!_C.FF`XE](`2`3@```````````````!@`0?C__X(]L'^,Z:8#
MB7T@!(!.````````````````&`!!^/__@CWX?HSII@.)?2`$@$X`````````
M```````8`$'X__^"/<!^C.FF`XE](`2`3@```````````````!@`0?C__X(]
M6'^,Z:8#B7T@!(!.````````````````&`!!^/__@CV0?HSII@.)?2`$@$X`
M```````````````8`$'X__^"/6A_C.FF`XE](`2`3@```````````````!@`
M0?C__X(]8'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CWX?XSII@.)
M?2`$@$X````````````````8`$'X__^"/>A^C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]@'^,Z:8#B7T@!(!.````````````````&`!!^/__@CVP
M?HSII@.)?2`$@$X````````````````8`$'X__^"/8A^C.FF`XE](`2`3@``
M`````````````!@`0?C__X(],'^,Z:8#B7T@!(!.````````````````&`!!
M^/__@CW0?HSII@.)?2`$@$X````````````````8`$'X__^"/7A_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]*'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CWH?XSII@.)?2`$@$X````````````````8`$'X__^"/6!_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]V'Z,Z:8#B7T@!(!.````
M````````````&`!!^/__@CU0?XSII@.)?2`$@$X````````````````8`$'X
M__^"/1!_C.FF`XE](`2`3@```````````````!@`0?C__X(]X'Z,Z:8#B7T@
M!(!.````````````````&`!!^/__@CVX?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/:A^C.FF`XE](`2`3@```````````````!@`0?C__X(]R'Z,
MZ:8#B7T@!(!.````````````````&`!!^/__@CV0?XSII@.)?2`$@$X`````
M```````````8`$'X__^"/=!_C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]0'Z,Z:8#B7T@!(!.`````````````````@!,/&!>0CBF`@A\\/_!^_C_
MX?L0``'X<?\A^'``@?AH`*'X<`"!.&@`H3A\`&&0?`!A.*W[_TL8`$'H````
M8%"`HN@```!@6(!BZ'@KI'SQ^/]+&`!!Z````&!@@"+I````8#B`XNL``,F+
M```>+$``@D!-^/]+&`!!Z````&```",LV)%B^!``@D`!`&`X4?[_2Q@`0>@)
M_?]+&`!!Z```?X"]^?]+&`!!Z*$+PYL``'^`K?G_2Q@`0>@*!B.)`@`I80H&
M(YD``'^`E?G_2Q@`0>@*!B.)`0`I80H&(YE\`&&`!0!C.+0'8WPD'V-XL?C_
M2Q@`0>A^`*'H<`#AZ````&````!@````.<B18OAX&V9\```GZ0``!2P``"/Y
M_O\B/8O?*3D(`"/Y````8'"!(ND0`"/Y_O\B/8[?*3D8`"/Y!``@.<"1(I'_
M_R4Y(``I>0$`*3D(`(%!`0`@.0$`*2P!``@Y__\I.=P`@D`$`"4Y``!`.0``
M`&#8D6+HM`<I?0,`I3@D'REY_O^"/!1*)GT``.`XM`>E?%2MA#CX_TGY'?O_
M2Q@`0>AY&W]\&`""0````&#8D6+HY?S_2Q@`0>AX&W]\````8-B18NA1^?]+
M&`!!Z/[_8CR7W6,X+00`2```(RP\`()`````8-"1(ND``"DL&`""0/[_8CQ,
MW6,X"00`2````&#0D6+X````8-"18N@``",L"`""02$=`$@```!@V)%BZ)7W
M_TL8`$'H+?G_2Q@`0>B0`"$X>/OC?WPW`$@D'PIY*E"'?`0`2#FT!TI])!]*
M>1121GWX_XKX_/[_2P`````````!@`(```(`3#SL6T(X*`",@!1BA'QX"R-\
MY`8A>````#CA_P'XI@,(?!$``$@TV`$``@!,/,!;0CBF`@A\"`"C./[_XCRL
MW.<X_O_"/+B9QC@````Y$``!^.'_(?@"`(/H_O]B/*"A8SB)^?]+&`!!Z"``
M(3@0``'HI@,(?"``@$X``````````8````````!@`@!,/&!;0C@```!@````
M8'B!8CAX@2(Y`!@I?"``@DT```!@"(""Z0``+"P@`()-I@((?*8#B7T0``'X
MX?\A^!@`0?@A!(!.&`!!Z"``(3@0``'HI@,(?"``@$X``$)@`@!,/`!;0C@`
M``!@````8'B!8CAX@8(X4""#?'0>A'QT#H1\E0&$?"``@DT```!@$(""Z0``
M+"P@`()-I@((?*8#B7T0``'XX?\A^!@`0?@A!(!.&`!!Z"``(3@0``'HI@,(
M?"``@$X```!@``!"8`(`3#R06D(X````8'B!(HD```DL(`""3*8""'P```!@
M&(`BZ>C_H?OP_\'[```I+!```?C!_R'X&`!!^!0`@D$```!@`(%BZ.GV_TL8
M`$'H__]"/?__PC\```!@@($BZ4!\2CDX?-X[4%#>?___HC]T'MY_.'R].___
MWCM`\"E\/`"`0#@`X?L```!@@('B.P$`*3DD'RIY```_^2I0G7VF`XE](02`
M3A@`0>@``#_I0/`I?-S_@$$X`.'K??[_2P```&`@@"+I```I+!0`@D'^_V(\
M+!MC.'GU_TL8`$'H0``A.`$`(#D```!@$``!Z.C_H>OP_\'K>($BF:8#"'P@
M`(!.````8````&```$)@`@!,/(!90C@```!@*(`BZ0``*2P\`()!I@((?```
M`&#^_V(\B(&"."P;8S@0``'XX?\A^(WS_TL8`$'H(``A.!```>BF`PA\0/[_
M2P``0F`X_O]+`@!,/"Q90CBF`@A\)30`2'D;?'RQ_R'X``#`.R0`@D$```!@
M,(`BZ0``P#MX(YI\>..%?P``J>L``#TL'`""0%``(3AX\\-_(#0`2#T`"2@4
M`()!`0"E.```)8D``"DL[/^"0%`HO'QXZ[M_M`>_?```V^L``#XLR/^"07C[
MY7]XXX1_>//#?X7V_TL8`$'H```C+"@`@D"N^#Y]/0`)+!P`@D!0V+U_`0#_
M.W0>O7\4^MY_``"ZDXC__TL(`'L[L/__2P`````````!@`8```(`3#Q<6$(X
MI@((?!```?B1_R'X9`"!./"/+>EH`"'Y```@.17__TMH`"'I\(]-Z7E2*7T`
M`$`Y#`""04'T_TL8`$'H<``A.!```>BF`PA\(`"`3@`````````!@`````(`
M3#S\5T(XI@((?/#_P?OX_^'[>!M_?!```?B!_R'X\(\MZ6@`(?D``"`Y9`#!
M.WCSQ']X^^-_H?[_2P``(RP@`()`:``AZ?"/3>EY4BE]``!`.3P`@D'%\_]+
M&`!!Z&8`(>DD'REY^/]).0```&`P@"+I```IZ112*7T0`$GI```J+`D`2?GT
M_X)`I/__2X``(3C(,@!(``````````&``@```@!,/%A70CBF`@A\33(`2%'_
M(?AX&W]\>".>?/"/+>EH`"'Y```@.0``)(D]``DL"`""0`$`Q#MX\\-_/??_
M2Q@`0>AD`($X>!M]?'C[XW_E_?]+>1M\?$P`@D$=]_]+&`!!Z$#H(WSP`(!!
M``!`.:Y0/GT``"DLKE$\?0$`2CGP_X)```!@.&@`(>GPCTWI>5(I?0``0#EP
M`8)!W?+_2Q@`0>@```!@,(!BZP``(#D``#OK^/\9.;0'/'T!`"DY)!\J>2I0
M2'T``"HL[/^"0````&"X@2*!`@"<.+0'A'PD'X1X```)+"0`@D%XRR-_:?'_
M2Q@`0>@``",L``![^$``@D#__V`X@/__2P$`(#D```!@>".#?+B!(I$]]_]+
M&`!!Z'D;>GS<_X)!)!^%>WC+)'^%]?]+&`!!Z```6_L``%OI`0`\.0```#DD
M'REY*DD*?60`@9-X^^E_``!)B0``*BP,`()!/0`**)0`@D!F`('K````8#"`
M8NM02#]]`@!].+0'*7T42F-\``!;Z\GV_TL8`$'H)!^<>P``(RPJX7I\8/^"
M068`(>D``%OI____.R0?*7DJ2"I]`0!?C7A+*'T!`"DY```J+/__29D,`()!
M/0`**.3_@D`]`$`Y``!(F0```#FN0%Y]```J+*Y!27T!``@Y\/^"0(C^_TL!
M`"DY6/__2[``(3B$,`!(``````````&`!P```@!,/#Q50CBF`@A\+3``2,'^
M(?AY&WU\\(\MZ?@`(?D``"`Y:`""00``/8D```DL7`""00GO_TL8`$'H>1M\
M?$P`@D'^_V(__O]"/_[_(C\#W7L[`MU:.P7=.3MH``$[>..#?SGR_TL8`$'H
M>1M_?#@`@D!XXX-_A?3_2Q@`0>AXZZ-_.?#_2Q@`0>CX`"'I\(]-Z7E2*7T`
M`$`YU`""0;WP_TL8`$'H$P#_.WC;9']X^^-_R?#_2Q@`0>@``",LH/^"07C3
M1']X^^-_L?#_2Q@`0>@``",LB/^"07CKHW]]]/]+&`!!Z'@;?GQX^^-_;?3_
M2Q@`0>@4&GY\`@!C.+0'8WPY]?]+&`!!Z'C[YG]XZZ5_>,LD?W@;?GRA\/]+
M&`!!Z'C#!']X\\-_T>[_2Q@`0>C__P,L>//#?R@`@D&``"&!)@0I50!`"2P8
M`()`N?[_2WCSPW^E\?]+&`!!Z`#__TMY[O]+&`!!Z.C__TM``2$X_"X`2```
M```````!@`@```(`3#RX4T(XI@((?/C_X?MX&W]\$``!^#'_(?@H`($X\(\M
MZ;@`(?D``"`YK?3_2Q@`0>@``",L5`""0$``(8$F!"E5`$`)*!``@D'__RIM
M`*`*+!P`@D`"`(`X>/OC?]GT_TL8`$'H-`!C?'[98U2X`"'I\(]-Z7E2*7T`
M`$`Y%`""057O_TL8`$'H``!@..#__TO0`"$XA"X`2``````````!@`$```(`
M3#P04T(XI@((?````&`X@"+I$``!^.'_(?@``&F`\>[_2Q@`0>@```!@0("B
MZ/[_PCS^_X(\^!G&.`O=A#CQ\/]+&`!!Z"``(3@0``'HI@,(?"``@$X`````
M`````8`````"`$P\K%)".*8""'SX_^'[````8#B`XNL0``'XT?\A^```?X")
M[O]+&`!!Z'G__TL``'^`>>[_2Q@`0>C^_^(\_O^B/(K?YSC^_X(\````.7@[
MYGSLO*4X)]V$.+'N_TL8`$'H,``A.*@M`$@``````````8`!```"`$P\-%)"
M.*8""'SX_^'[\/_!^Q```?AAWR'X\(\MZ8@@(?D``"`YC>S_2Q@`0>AX`.$[
M_O_"//[_@CQX&V5\/-W&.$#=A#AX^^-_:>[_2Q@`0>B`$($X>/OC?P`0H#@`
M`.`[:`"!^,WQ_TL8`$'H```#+#@`@$&T!WY\`0!^.+0'8WRQ\O]+&`!!Z'D;
M?WP<`()!:`"!Z'CSQ7_Y\O]+&`!!Z```(#FN\3]]B"`AZ?"/3>EY4BE]``!`
M.0P`@D&5[?]+&`!!Z*`@(3AX^^-_Q"P`2``````````!@`(```(`3#Q444(X
M(/__2P````````````````(`3#P\44(XI@((?":`D'T(`(&1%2P`2*'N(?AX
M&WY\_O]B/$S=8SAX(Y]\\(\MZ?@0(?D``"`YL?C_2R\`@#AX&WM\>//#?Q7L
M_TL8`$'H```C+#``@D'^_V(\>//$?U7=8SB)^?]+^!`AZ?"/3>EY4BE]``!`
M.7@!@D'A[/]+&`!!Z'CSPW_^_T(_T?#_2Q@`0>ABW5H[_O\B/WC31'_^_^(^
MM`=]?'C[XW]Q\?]+&`!!Z/[_PCX``(`Z```[+@/=.3MX&W]\````.P$`O3MD
MW?<Z-=[6.O@`@3MH`*$Z`("48@``/RQP_X)!```_B0``"2P(`()`>,L_?R``
MDD%X^^1_>-MC?W7L_TL8`$'H>--$?P``(RS(`()!>/OC?SWP_TL8`$'HM`=I
M?!1*7WW__TJ)+P`*+)``@D$42CU]_P\)+!3_@4%X\\=_>+OF?GC[Y7]XL\1^
M>..#?V'L_TL8`$'H>*ND?GCC@W^1ZO]+&`!!Z```(RQ@`()`@``A@28$*54`
MH`E\4`""0`$`@#AXXX-_*?'_2Q@`0>@``",L.`""0/[_8CQXXX1_5=UC.#WX
M_TMXXX-_Y>__2Q@`0>AX&WY\I/[_2___*3FT!RE]KDD??UC__TMXTT1_``!@
M.#WP_TL8`$'H>!M_?/C^_TM@$2$X>//#?P@`@8$@@9!]8"H`2``````````#
M@`P``/__(SD!`$F)`0`).0``*BP@`()-+P`**`(`*3D(`()`>$LC?7A#"7W<
M__]+`````````````````@!,//1.0CBF`@A\^/_A^WD;?WP0``'XT?\A^!``
M@D$``#^)```)+!``@D#^_V(\`]UC.!0!`$C=[O]+&`!!Z/__(SD42K]\>!MI
M?!0:?WS__V,X0!@_?`P`@4'__S\L"`""0`$`(#D!`"DL__\I.;P`@D$``$6)
M+P`*+)P`@D'__T4Y4"@_?4!0/WP(`(%``0`@.0``18EX*ZA\__^E."\`"BA\
M`()`>$,%??__13E0*#]]0%`_?`P`@4'__S\L"`""0`$`(#D!`"DL__^E./__
M*3D0`()!``!%B2\`"BSH_X)!4"B_?```8#@"`"4Y`!`I*%P`@4$```!@`0"E
M.,"!(CEX^^1_>$LC?8GM_TL8`$'H/```2/__I3A,__]+`0`I+/__*3EL_X)`
M0"@_?'S_@D```#^)_O]B/&3=8S@O``DLZ/Z"00WN_TL8`$'H,``A.`0I`$@`
M`````````8`!```"`$P\D$U".*8""'S^_V(\9MUC.(DH`$A1_R'X_O_"/_[_
MHC^'W=X[3-V]._[_XC_^_X(_H]W_.ZW=G#OPCRWIB``A^0``(#G^_R(]`AHI
M.0``R>@(`.GH$``)Z1@`2>D@`"FA8`#!^&@`X?AP``'Y>`!!^8``(;$E]?]+
M_O]B/&_=8S@9]?]+_O]B/'?=8S@-]?]+_O]B/(#=8S@!]?]+>//#?_GT_TO^
M_V(\E]UC..WT_TMXZZ-_Y?3_2WC[XW_=]/]+>..#?]7T_TO^_V(\M]UC.,GT
M_TO^_V(\5=UC.+WT_TO^_V(\P=UC.%'T_TMY&V1\#`""07CC@W]%]?]+_O]B
M/-+=8S@U]/]+>1MD?!``@D'^_V(\W=QC."7U_TO^_V(\Y-UC.!7T_TMY&V1\
M.`""07CKHW\)]?]+_O^"/'CSPW\0WH0X^?3_2X@`(>GPCTWI>5(I?0``0#E0
M`()!4>C_2Q@`0>C^_V(\]-UC.,WS_TMY&V1\#`""07C[XW^X__]+_O^"/`H`
MH#@%WH0X<0!A.-WI_TL8`$'H```C+)S_@D![`($XU/__2[``(3@D)P!(````
M``````&`!````@!,/-!+0C@```!@"($B@?__"2Q@`()`I@((?/[_8CRCW6,X
M$``!^*'_(?A1\_]+``!`.0``(RP<`()!```CB0``*2P0`()!,``I:?__23$0
M24I]````8&``(3@(@4*1$``!Z````&"F`PA\"H%BZ"``@$X```!@"H%BZ"``
M@$X``````````8`````"`$P\1$M".*8""'P0``'XX?\A^#'J_TL8`$'HR>O_
M2Q@`0>@``",L"`""00``8^@@`"$X$``!Z*8#"'P@`(!.``````````&`````
M`@!,//A*0CBF`@A\^24`2('_(?C^_X(_>!M_?!+>G#MXXX-_@?+_2WC[Y']Y
M&WY\$`""00``/HD```DL%`""0'CC@W]E\_]+@``A./`E`$C)Z?]+&`!!Z```
M(RSL_X)`>/OC?[7J_TL8`$'H>!M]?'CSPW^EZO]+&`!!Z!0:?7P"`&,X=>O_
M2Q@`0>C^_\(\_O^"/#7>A#AX\\=_>!M]?&+=QCAX^^5_T>;_2Q@`0>AXZZ1_
MC/__2P`````````!@`0```(`3#PT2D(XI@((?```(#F8@2EA&24`2/__`#S^
M_T(_$'X`8$S=6CMX&WM\>--#?VH!(7P4"BE]H('A._"/3>D``$GY``!`.0``
M`&`0@2+IP'X_^0```&`8@2+IR'X_^0```&`@@2+IT'X_^0```&`H@2+I\'X_
M^0```&`P@2+I^'X_^0```&`X@2+I`'\_^0```&!`@2+I"'\_^0```&!(@2+I
M$'\_^0```&!0@2+I&'\_^0```&!8@2+IV'X_^0```&!@@2+IX'X_^0```&!H
M@2+IZ'X_^0GQ_TMY&WY\3`""00``/HD```DL0`""057^_TMX\\-_G>G_2Q@`
M0>AX&WY\```@.9B!*6$4"BE]``!)Z?"/+>EY2DI]```@.>@%@D$QY?]+&`!!
MZ,W]_TO0?K\[>1M^?)`!@D%X\\-__O^"/Q'I_TL8`$'H___>.RG>G#ND#V-X
M`0!C.-GI_TL8`$'H>!MY?'@;?7P!`+Z,```E+&P!@D#H?K\["0#=ZP``/BP\
M`()!>//#?U7P_TMY&WY\Z/^"00``/HD```DLW/^"0>'T_TL``",LT/^"07CS
MPW_AZ/]+&`!!Z'@;?GRX?I\[```^+!P`@D`)`+SK```]+$@!@D$``#V)```)
M+!@!@D!X\\-__O\"/VGH_TL8`$'H9-T8.W@;?'QXRR-_5>C_2Q@`0>@4&IQ_
M!`2<.[0'G']XXX-_'>G_2Q@`0>C^_^(\_O^"/'C+*'\NWN<X>,,&?WCSQ7\S
MWH0X>!M]?'7D_TL8`$'HP`&`.'CKHW_%X_]+&`!!Z/__`RS(`()`%>G_2Q@`
M0>@"`./H$0`'++0`@D$```!@2(`BZ0``N^C^_X(\>.NF?SS>A#@``&GH)>;_
M2Q@`0>@``,`[:/[_2T'O_TMY&VE\(`""00``*8D```DL%`""0=WG_TL8`$'H
M>1M^?'C^@D`)`'WH```C+-#_@D#^_\(_(M[>.V#^_TMXZZ-_>..$?\WC_TL8
M`$'H`@"].WC^_TMXZZ-_B?/_2P``(RS(_H)!>.NC?XGG_TL8`$'H>!M^?*S^
M_TL``,`[Q/[_2R!_GSAXZZ-_*>C_2Q@`0>AY&W=\+`""00```&!(@"+I``"[
MZ/[_@CQXZZ9_=]Z$.```:>A=Y?]+&`!!Z#C__TLX?S^!)@0I50!`"2S,_X)`
M/'_?@[WE_TL8`$'H`!@^?+C_@D`X?S^!_@4I5<`!"2RH_X)`>..#?YGG_TL8
M`$'H>!M^?/[_8CP=WF,X,>[_2P``(RRL`8)````[ZWC+(W^1YO]+&`!!Z`,`
M`RRT!WQ\B`"!0/S_?#C^_X(\RMZ$.!0:>7R-XO]+&`!!Z```(RQH`()`!``<
M+!P`@D'\_YP[M`><?Q3BF7___SR)+P`)+$@`@D`(`)OK```\+#P`@D%XXX-_
M+>;_2Q@`0>@#`",H*`"!0/S_8SC^_X(\S]Z$.!0:?'PMXO]+&`!!Z```(RP(
M`()`>..9?Q'Z_TL``",L\`&"0```@#AXRR-_A>;_2Q@`0>AY&WQ\V`&"00(`
MH#CN_X`XC>3_2Q@`0>CX?W\[!@"@.'C;9']XXX-_=>7_2Q@`0>CX?S^)```)
M+-@`@D#Y?S^)0P`)+,P`@D#Z?S^)00`)+,``@D#[?S^)0P`)++0`@D#\?S^)
M2``)+*@`@D#]?S^)10`)+)P`@D`"`*`XQO^`.'CC@W\9Y/]+&`!!Z"D`H#AX
MVV1_>..#?P7E_TL8`$'H_O\"/7C;9W^*WP@Y_O^"/'C#!G]XZZ5_U-Z$.'CS
MPW]]X?]+&`!!Z'CKHW^QXO]+&`!!Z'CSQ']XTT-_D>W_2WCSPW_I^?]+I/O_
M2P``F^LMY?]+&`!!Z'@;9'QXXX-_B?/_2WD;>7Q`_H)`./[_2P``H#@``(`X
M>..#?___X#I]X_]+&`!!Z/A_/SL@!/=6C1L`2````&!X&WM\>+OE?GC+)']X
MXX-_5>3_2Q@`0>@```,LM`=E?'``@4%XXX-_L'^?.QGC_TL8`$'H>-MD?WCC
M@W_^_^(^R'\_.Q4=`$@```!@``!@.RG>]SJNV+Q\>,LC?WB[Y'X!`'L[`@`Y
M.YW@_TL8`$'H%``[*.#_@D```"`Y_O\"/8K?"#G(?_\X\'\_F>C^_TMXRR1_
M>-MC?X$;`$@```!@9/__2_[_@CS^_V(\$-Z$.*/=8SB![/]+_O_B/_[_@C^*
MW_\[\=Z<.SW>_TL8`$'H_O^"/'C[Z']XPP9_>.NE?W@;9WSCWH0X>//#?QG@
M_TL8`$'HP`&`.'CSPW]IW_]+&`!!Z/__`RR(_H)`N>3_2Q@`0>@``".!$0`)
M+'3^@D#EW?]+&`!!Z`$`]SIX^^E_M`?W?GC#!G]X&V=\>+OH?GCKI7]XXX1_
M>//#?[G?_TL8`$'HH/__2P``(>AX\\-_5!X`2``````````!@`D```(`3#P4
M0T(XI@((?`4>`$A1_R'X````8#B`XNL``'^`]=[_2Q@`0>AX&WY\``!_@.7>
M_TL8`$'HN``^B;D`(YG^_V(\A]UC.'GJ_TL``",L'`""00``0XDQ``HL$`""
M0`$`(XD```DL"`""02'U_TL``'^`````8+B!HCN9WO]+&`!!Z/[_@CP+`,`X
M`0"@.`+?A#C!X/]+&`!!Z```(RR8`()```!_@&W>_TL8`$'H_O^"/`,`P#@!
M`*`X!]^$.)7@_TL8`$'H>1M^?'0!@D```'^`0=[_2Q@`0>C^_X(\`P#`.`$`
MH#@GWX0X:>#_2Q@`0>AY&WY\V`&"0?[_8CQ5W6,XO>G_2WD;97QH`*'XB`&"
M00``?X#]W?]+&`!!Z!``/NEH`*'H``")Z,G>_TL8`$'HG`$`2!``(^D@`"`_
M`0#`.P`$.6,H`$GK"!`]@?__?CL``'^`M`=[?P#P"7PH`(%`L=W_2Q@`0>@`
M`,`X>-ME?WC31'\=X?]+&`!!Z'D;?'P@`()`````8,"1HH#__Z4X`-@%?`S_
M@D`!`,`[C```2!`07>DD'\E[*D@*?P``7.D,`"J!.$@I?P`$"2PH`()`$`"*
MZ'C#`W^)W?]+&`!!Z```(RRP_X)``0#>.[0'WG]H__]+``!_@"G=_TL8`$'H
M``"<Z`(`P#@``*`XM=[_2Q@`0>AX&V1\O/__2P7=_TL8`$'H>--$?P$`WCNT
M!]Y_D=S_2Q@`0>@($#V!``!_@`#P"7S8_X%!:/[_2P``?X#1W/]+&`!!Z!``
M/NG^_Z(\"=^E.```B>B9W?]+&`!!Z!``/ND``"GI#``I@4``*75<_H)!``!_
M@)G<_TL8`$'H$``^Z0``B>C)W?]+&`!!Z#S^_TM1[O]+>1M\?```?X#0`()!
M;=S_2Q@`0>@0`#[I>..%?P``B>@YW?]+&`!!Z'CC@W\-WO]+&`!!Z```?X!!
MW/]+&`!!Z'@;?GP``'^`,=S_2Q@`0>C^_X(\`0"@.`[?A#@]VO]+&`!!Z/[_
MHCPCWZ4X>!MD?'CSPW_EW/]+&`!!Z```?X#YV_]+&`!!Z```(#FY`".9_O]B
M/$S=8SB-Y_]+````8```(RS0D6+X3`""0````&#(D6+HF?7_2P```&```",L
MT)%B^#``@D#^_V(\*=]C.,G<_TL8`$'HH=O_2Q@`0>@```!@R)%"Z1``/ND`
M`*KHG/W_2P```&#0D6+HP`&`.%G;_TL8`$'H$0`#+'@;9GPL`()!`0`C.0$`
M"2@@`(%`$!`]Z1@0O>C^_V(\2M]C.```B>AEW/]+&`!!Z+``(3AL&@!(````
M``````&`"````@!,/"@_0CBF`@A\\/_!^_C_X?MX&WY\$``!^)'_(?@=\/]+
MV>__2W@;?WPU\_]+```C+%``@D$``#XL2`""00``/HD```DL/`""0?[_@CQX
M^^-_+MZ$./'=_TL8`$'H`!@_?"``@D!P`"$X>//#?Q```>CP_\'K^/_AZZ8#
M"'QTZ?]+<``A.``:`$@``````````8`"```"`$P\D#Y".*8""'PX`,,X?1D`
M2!'](?CPCRWIJ`(A^0``(#D(`"`YI@,I?2@``3D``$;I+#0@?1``"#D(`,8X
M\/\H^2#"27DB`$=Y+@0I52!&2GEX4RE]*,#J>'A3*7T>0N=4>#LI??C_*/G$
M_P!"0``@.2```3FF`RE]<``HZ4@`Z.@8`$CI>#HI?7A2*7T)`$CI>%(I?:0/
M*GG"#REY>$M)?2``*7F``"CYT/\`0@```^@@`&/I"`"#Z!``P^@8`*/HPBX)
M>*0N!WAX2^=\*``AZ63PBG@@`.=X>"K(?#@@"'UD\!]X@EHI/7@J"'V9>2DY
M%%HI?11*YWR"\(EX>$M*?3``(>D40N=\(`!<>2``_GAXXLA\@EHI/3@`"'V9
M>2DY>#((?10J*7T42@A]R"[I>.(NYWAX.R=]@O`)>!0Z"'TX`.'H>$O_?WCZ
M27T@`!IY./`I?<@N"GF"6N<\>.(I?9EYYSCB+@AY%#+G?'A#2'T4.BE]9/#*
M>Q1"*7U```'I@O#>>WCS2GT@`/U[>%+L?R``.WF"6@@].-",?9EY"#EXZHQ]
M%.*(?V3P1WO(+BAY@O!:>^(N*7EXT^=\>$L)?13BC'T42HQ](`!>>7@Z27U(
M`$'I9/!H>SC8*7V"\'M[>/(I?2``G'F"6DH]>-L(?9EY2CD@`/IX%.JJ?U``
M0>ED\)][%.HI?<@NG7GB+HQY(``;>7ACK'^"6DH]>$+]?)EY2CDXX+U_%&(I
M?13RRG]XTKU_(``X>13RO7_(+CYYXBXI>7A+R7^"\)Q[%$J]?U@`(>EXX_]_
M>/H>?63P"GLXP-Y_@O`8>X):*3UXPTI]F7DI.2``N7L4TDE_8``AZ<@NK'MX
MVMY_XBZ]>WCKG7T4TMY_@EHI/7A2['^9>2DY%.K>?Q3::7\XR(Q]9/`I>X+P
M.7MXRRE](`#=>\@NQWOB+MY[>//^?'A*1WT@`/Q[..CG?&3PJ'N"\+U[>.L(
M?7CBC'UX0CU]%-J,?2``.WEP`"'I(`!:>6@`0>D4\HQ]>-+G?"``F'F"6BD]
M@EI*/9EY*3F9>4HY%-))?W@`(>D4XHI_R"Z*>>(NC'EX8TQ]%.+G?!1BYWPX
MP+U_9/`?>X):*3V"\!A[(`#Y>'C#_W_(+OYX>-J]?YEY*3GB+N=X%-II?X``
M(>EX.\=_%-*]?WCZ'GT@`!QY%#J]?SC(WG\@`*=[R"ZL>WCBWG_B+KU[>.N=
M?13:WG]D\"I[@EHI/8+P.7L4ZMY_>,M*?9EY*3D@`-A[>%+L?Q3BB7_(+LE[
MXB[>>R``^GMX\SY].#B,?63PZ7B"\.=X>#LI?7C2C'UX2D=]%.*,?13RC'TX
MP.=\9/`(>X+P&'MXPPA](`"9>2``6WG(+IUYB`!!Z>(NC'D@`#QY>&.L?WA"
M/7V0`"'I@EI*/7C:YWR9>4HY.,B]?X):*3T4TDI_F7DI.132YWP4VFE_F``A
MZ11BYWP@`.QXR"[^>'CBO7_B+N=X>#O'?Q3:O7^"6BD]%#J]?V3P/WN9>2DY
M@O`Y>R``N'MXR_]_%.*)?\@NJ7OB+KU[>/H>?7CK/7V@`"'I(``:>3A@WG]D
M\(IY@O",>7AC2GUXTMY_>%+L?Q3BWG^"6BD]%.K>?R``^WLXP(Q]F7DI.63P
M!WN"\!A[(`#9>WC#YWP4TDE_>-J,?<@NR7OB+MY[(`!<>7CS/GT4THQ]>#I)
M?:@`0>D4\HQ].,@I?63P/WN"\#E[(`"=>7C+_W_(+HAYXBZ,>2``^GAX8PQ]
M@EI*/7CZZ'RP`.'HF7E*.13::G]XXBE]%-HI?3CH"'V"6N<\%&(I?9EYYS@@
M`"IY%.*'?WC2"'W(+B=YXBXI>7A+Z7P4X@A]N`#AZ!1*"'UD\*E[@O"]>R``
M_GMXZRE]9/!=>7A*_W\@`#EY.%#_?X+P2GEX4[U_@EKG/'CJ*GW``"'IF7GG
M."``''D4TD=_>/+_?^(N!WDH*`AY%-+_?W@["'V"6BD]%$(??3C@2GV9>2DY
MXBX'>13RR7]XRDI]*"@)>13R2GUX.RE]9/";>Q1*2GW(`"'I@O"<>WCC>W\H
M*%]Y>-J\?XCP'GG:;BD]>$*<?Z'K*3FB\`AY%,HI?^(N27EX2_]_T``AZ7A#
MR'_@`,'K>$)G?R``G'L4RIQ_(`"]>]IN*3UX4N=\H>LI.13ZG'\4ZBE](`#G
M>!0Z*7TH*)U[XBZ'>R``>WMX.[U_V`#AZ-INWC\4ZJE_B/!)>:+P2GGB+K][
M>%,J?=INYSQX4@E]H>OG.'CB*7T4VN=\(``I>2``"'D42N=\*"BI>WC[*7V(
M\)][HO"<>Q1*YWQXX_Q_H>O>._``X>MXXDE]%$+>?WCJ*7TH*.AX(``I>2``
M2GD42MY_XB[I>'A+"'V(\*E[HO"]>Q1"WG]XZSU]Z``AZ>(NR'N(\/MXVF[_
M/Z'K_SO:;BD]H>LI.112*7UXZHI_>#I*?:+PYW@@`$IY>#M[?Q12*7TH*,I[
M>$-*?2``G'L44BE]>-JJ?WCR2GT4XO]_(`!*>>(N*'D44O]_*"@J>7A#2GV(
M\,A[%%+_?_@`0>FB\-Y[>/,>?2``O7MX\FA_XB[G>]IN2CUX2@A]H>M*.2``
M"'D4ZDI]B/`]>11"2GTH*.A[>#L(?0`!X>BB\"EY>$N]?R``>WMXZLE_%$)*
M?=INYSQX^BE]H>OG."``*7D4VN=\XBY(>11*YWPH*$EY>$,I?0@!`>F(\/M[
MHO#_>Q1*YWQX^WM_(`#>>WC:J7_:;@@]>%(I?:'K"#D4\@A](``I>>(N_W@4
M2@A]*"CI>(CP7'EX^RE]HO!*>11*"'T0`2'I>%.<?WCB:G\@`+U[>#I*?>(N
M'WG:;BD](`!*>:'K*3D@`'M[%.HI?8CP_7@44BE]*"@*>7C[2GT8`>'KHO#G
M>'@[O7\44BE]>.J*?^(N)WG:;O\_>$)*?:'K_SL@`$IY%-K_?XCP'GD44O]_
M*"@J>7@[2GVB\`AY%%+_?R`!0>EX0]Y_>/*H?R``G'MX2@A]XB[G>]IN2CT@
M``AYH>M*.2``O7L4XDI]B/`\>11"2GTH*.A[>#L(?2@!X>BB\"EY>$N<?Q1"
M2GUXXLE_XBY(>=INYSQX^BE]H>OG."``*7D4ZN=\B/#]>Q1*YWPH*$EY>$,I
M?3`!`>FB\/][>/N]?Q1*YWQXZHE_(`#>>]IN"#UX4BE]H>L(.2``*7D4\@A]
MXB[_>!1*"'TH*.EX>/LI?8CP7GD42@A].`$AZ:+P2GEX4]Y_(`"<>WCRJG_B
M+A]YVFXI/7@Z2GVAZRDY(`!*>13B*7V(\/MX%%(I?2@H"GEX^TI]0`'AZZ+P
MYWAX.WM_%%(I?7C:RG\@`+U[VF[_/WA"2GVAZ_\[(`!*>13J_W\H*#UY%%+_
M?^(N*GEX4[U_2`%!Z8CP''FB\`AY(`#>>WA#G'\4ZK]_>.)H?]IN2CUX2@A]
MH>M*.13R2GT@``AY%$)*?2@HOGOB+JA[B/`Y>7A#WG^B\"EY%/+*?U`!0>EX
M2SE_(`![>XCPJ'NB\+][XB[)>]INZCQXRHI_>.I*?:'KYS@4VN=\(`!*>112
MYWQ8`4'I>/L??2@HVWL@`)Q[>$M[?WCZ*7_:;@H]>/(I?:'K"#D4VF=_%.((
M?2``*7GB+FI[%$H(?<@N:7L@`#E[>%,I?:+PRGL42@A]B/#)>WA3/GU@`4'I
M(``:>:+P9WL@`-Q[9/!=>]IN*CUX\NI_>-I*?:'K*3D4RBE](`!*>112*7W(
M+@IYXBX(>2``_WMX0TA]B/!J>W@[1WT40BE](`#[>'@[R'\XV,I_.-`(?6@!
MP>MX4PA]&X]`/=R\2F&"\%I[(`!*>7C3O7\4\LI_(``Y>13Z_G]XZ^=\%/H(
M?<@N/WGB+BEY.,CG?'A+Z7\XV+]_>/OG?'`!X>L42BA](``H>63P+'N"\#E[
M(`"Z>Q3ZZG]XRXQ]%.*??\@N/WGB+BEY%.+G?'A+Z7\@`)QY%$KG?'@!(>EX
M8[Y_.$#>?SC@O7\@`/AX>.O>?Q1**GT4VFE_R"[I>.(NYW@4VMY_>#LG?10Z
M_GQD\!YY@O`(>2``^7AX0]Y_@`$!Z7CSB7TXX,Q_.,`I?2``VWL40@I]>&,I
M?1322'_(+NAXXB[G>!32*7UX.P=]9/`(>X+P&'L4.BE]>,,(?2``.GD@`!UY
M>$/??SCHQW\XR/]_>#O_?X@!X>AD\$Q[%#KJ?!3BAW_(+B=YXBXI>13B_W]X
M2^E\%$H_?63P/WN"\#E[(``X>7C+_W]X^P=]..CH?SC0YWR"\%I[>$/G?)`!
M`>EXTXQ]>&/^?R``_'LXP-Y_%$(*?13::'_(+BAYXBXI>13:YWQX2PE](`";
M>:`!`>D42N=\.-CI?WA+WG^8`2'I(`#Y>!1""GT4XHA_%$HJ?13JJ7_(+NEX
MXB[G>!3JWG]X.R=]%#K^?&3P'GN"\!A[(`#Z>'C#WG_(+NAX>/.)?>(NYW@X
MV,Q_>#L'?3C(*7UD\"A[@O`Y>WAC*7UXRPA]%.(I?7A#WW\@`!QY%#HI?3C0
M_W\XX,=_(``X>7@[_W^H`>'H(`#=>V3P#'L4.NI\%-IG?\@N)WGB+BEY%-K_
M?WA+Z7P42C]]9/!?>X+P6GL@`#EY>-/_?WC[!WTXX.A_.,#G?(+P&'MX0^=\
ML`$!Z7C#C'UX8_Y_(`#[>SC(WG\40@I]%.JH?\@N*'GB+BEY%.KG?'A+"7T@
M`)UYP`$!Z11*YWPXZ.E_>$O>?[@!(>D@`/IX%$(*?13::'\42BI]%.*)?\@N
MZ7CB+N=X%.+>?W@[)WT4.OY\9/`^>X+P.7L@`/AX>,O>?\@NZ'AX\XE]XB[G
M>#CHS']X.P=].-`I?63P2'N"\%I[>&,I?7C3"'T4VBE]>$/??R``&WD4.BE]
M.,#_?SC8QW\@`#EY>#O_?\@!X>@@`-Q[9/`L>Q0ZZGP4ZJ=_R"XG>>(N*7D4
MZO]_>$OI?!1*/WUD\!][@O`8>R``.GEXP_]_>/L'?3C8Z'\XR.=\@O`Y>WA#
MYWS0`0'I>,N,?7AC_G\@`/U[.-#>?Q1""GT4XHA_R"XH>>(N*7D4XN=\>$L)
M?2``G'G@`0'I%$KG?#C@Z7]X2]Y_V`$AZ2``^'@40@I]%.JH?Q1**GT4VFE_
MR"[I>.(NYW@4VMY_>#LG?10Z_GQD\%Y[@O!:>R``^7AXT]Y_R"[H>'CSB7TX
MX,Q_.,`I?>(NYWAX8RE]>#L'?13J*7UD\`A[%#HI?8+P&'OH`>'H>,,(?63P
M/7MX0]]_(``L>10ZZGPXR/]_@O`Y>Q3BAW]XR[E_R"XG>>(N*7D@`!MY>$OI
M?'C+!WTX8.=\.-@H?R``VGMX0^=\\`$!Z3C8WG]X\_]_%.+_?Q1""GT42C]]
M%-)(?R``/GG(+BAYXBXI>132YWQX2PE]9/"?>11*YWSX`2'I@O",>7AC_W\@
M`/IX>/L]?R``['L42BI]./"]?Q3::7_B+NEX*"CG>#A@*']X2^=\9/#)>X+P
MWGMX0[U_>/,I?13:O7]X2_]_.&`H?3C0_W\@`#Q[>$/_?P`"`>D4.OU\(``[
M>8CP_7@40DI]*"CH>!3B2GT44E]]XB[_>'C["'T(`N'K%$)*?63P2'N"\%I[
MXBY>>7C3&GUXTBA]8LH@/=;!*6%X.@A](``I>2``"'D4^NE_%&*??2@H7WEX
M\_]_%&((?13Z"'VB\/]X$`+AZ'C[OW_B+AUY>/I>?R``6GL4.NE\>%+>?Q3:
M9W\@`-Y[*"@'>13:WG]XZ^=\%#K>?XCP1WFB\$IYXB[<>WA3ZGP8`N'H>%+]
M?R``_WMX0KU_%#KI?"``O7L4TN=\%.KG?"@HW7MXX[U_%.KG?(CP'7FB\`AY
MXB[\>'A#J'\@`J'KB/#[>!3JJ7\4^KU_>$)??7CR_W\@`$IY(`#_>Q3ZO7\H
M*/]X>./_?Q3ZO7^(\-][HO#>>^(NO'MX\_Y_*`+AZQ3ZZ7\44O]_>/(*?7@Z
M2GVB\.=X(`!*>7@[>W\44O]_*"BJ>WCC2GT@``AY%%+_?S`"0>F(\+Q[XB[G
M>Q1227T40DI]>-K(?WCJ"'VB\+U[(``(>7CKG'\40DI]*"CH>W@["'UXXF=_
M%$)*?3@"`>D@`-Y[>/KG?"``>WL@`.=X%$()?13R"'WB+EYY%#H(?2@H1WEX
M\^=\B/#^>Q0Z"'VB\/][0`+AZ'C[WW_B+AUY>/J>?R``G'L4.NE\>%+>?Q3:
MYWP@`-Y[%/+G?"@H'GEXZ]Y_B/!;>4@"H>NB\$IY%/+G?'A3>W_B+OYX>-KJ
M?Q3JJ7]X0DI]%.*]?R``2GF(\!QY%%*]?R@HZGAX\TI]HO`(>5`"P>MX0YQ_
M%%*]?WCB:G\@`/][%/+)?W@Z2GT4^MY_(`!*>>(NJ'L44MY_*"BJ>XCP_WAX
M0TI]HO#G>!12WG]8`D'I>#OG?W@ZB'\@`'M[>.H(?>(NWWL44DE](``(>13:
M2GV(\+M[%$)*?2@HR'MX^PA]HO"]>Q1"2GU@`@'I>.M[?WC:_WP@`)Q[>/+_
M?^(N77D40@E](`#_>Q3B"'V(\-Q[%/H(?2@H7WEXZ_]_HO#>>W`"H>L4^@A]
M:`+AZWCSG'\@`.=XXBX>>13JJ7\4^NE_%#K_?WCB9W]X4N=\(`![>R``YW@4
MVKU_%#K_?R@H!WEX\^=\B/`;>10Z_W^(\$=YHO!*>>(N_GMX4^I\>%*'?R``
MG'MX0N=\HO`(>2``YWAX0WM_%#J]?R@HYWMX\^=\>`+!ZWC:2'UX^@A]%#J]
M?R``"'GB+J=[%/+)?R``2GD4XMY_B/#\>Q1"WG\H**A[>#L(?8`"X>BB\/][
M>/N<?Q1"WG_B+LA[%#KI?!12YWQXXFI_>.I*?2``>WL@`$IY%%+G?"@HRGMX
M0TI]B`(!Z112YWR(\*I[HO"]>^(N_WAXZUU]%$()?7CJBG\4V@A]>/)*?2``
MG'L@`$IY%%((?2@HZGAX^TI]D`+AZQ12"'V(\,I[HO#>>WCS7GT4^NE_>/*J
M?Q3B_W]X.DI]XBX<>2``2GD@`+U[%%+_?R@H"GEXXTI]%%+_?XCPZGBB\.=X
MXB[\>W@[1WV8`D'I%%IG?2``:WD44DE]%.I*?7@ZW7\@`&/Y>$*]?R``WGL@
M`+U[%.I*?<@N_7MXX[U_%.I*?8CP'7FB\`AY%"**?'A#J'^@`J'K(`"$>!0J
MJ'P@`*5X"`"#^!3J*7T4`BE]>$+@?!@`H_AX^@!\%/(I?2```'CB+EYY%`(I
M?<@N0'EX\P!\HO#J>Q0"*7T@`"EY```C^8CPZ7MX4RE]%#+)?"``QG@0`,/X
MJ`(AZ?"/3>EY4BE]``!`.0P`@D%%Q?]+&`!!Z/`"(3A,!`!(``````````&`
M"````@!,/`@I0CBF`@A\@`!@.!```?CA_R'X\<G_2Q@`0>A%9T`](``A.`$C
M2F$``$/YS>]`/8FK2F$@`$IY"`!#^;J80#W^W$IA(`!*>1``0_DR$$`]=E1*
M81@`0_G2PT`]\.%*82``2GD@`$/Y``!`.7@`0Y$H`$/Y,`!#^1```>BF`PA\
M(`"`3@`````````!@`````(`3#QT*$(XI@((?"0?J7AI`P!(L?\A^'@;?GQX
M(Y]\>"N]?"@`0^D44BE](``I>4!(*GP0`(%`,`!#Z0$`2CDP`$/Y>@!^Z#``
M7NDH`#[Y0A^I>S@`GCL``",L%$HJ?3``/OE8`()!0``C(7CKNW\`2!U\"`"!
M0'A+.WVT!WI_>/OD?WC317\4&GQ\2<G_2Q@`0>AX`#Z!%-HI?4``"2QX`#Z1
M.`""0%#HNW\4TO]_M`>]?WCSPW\UZ?]+/P`=+"0`@4%XZZ5_>/OD?WCC@W\%
MR?]+&`!!Z'@`OI-0`"$XT`(`2```_^@(`!_I$`!?Z1@`/^G`_[T[0`#_.[0'
MO7\``/SX"``<^1``7/D8`#SYX/__Z.C_'^GP_U_I^/\_Z2``_/@H`!SY,`!<
M^3@`//F$__]+``````````&`!@```@!,/#0G0CBF`@A\*``D.8#_0#DI`@!(
ML?\A^#@`I#MX&WY\>".??"Q,@'\P`"0Y+$Q@?R@`).F^[B55HNXI>0$`I3@X
M``4LM`>C?*Y)77T4&GU\-`&!0$``I2```(`XM`>E?''%_TL8`$'H>/OC?SWH
M_TLX`*`X``"`.'CKHW]5Q?]+&`!!Z'``?Y-T`)^3>/OC?QGH_TL``#_I>/OC
M?P)&*7D``#Z9```_Z0*$*7D!`#Z9```_Z0+"*7D"`#Z9```_Z0,`/ID(`#_I
M`D8I>00`/ID(`#_I`H0I>04`/ID(`#_I`L(I>08`/ID(`#_I!P`^F1``/^D"
M1BEY"``^F1``/^D"A"EY"0`^F1``/^D"PBEY"@`^F1``/^D+`#Z9&``_Z0)&
M*7D,`#Z9&``_Z0*$*7D-`#Z9&``_Z0+"*7D.`#Z9&``_Z0\`/ID@`#_I`D8I
M>1``/ID@`#_I`H0I>1$`/ID@`#_I`L(I>1(`/ID@`#_I$P`^F7W#_TL8`$'H
M4``A./```$@X`*4@``"`.+0'I7SL_O]+``````````&`!0``````8````&``
M``!@````8`(`3#R`)4(X__^"/2A\C.GX_^'[___B/]'_(?@P?/\[__\L+#P`
M@D&F`@A\&`!!^/C__SM```'X````8```0F"F`XE](02`3A@`0>CY_Y_I__\L
M+.S_@D!```'HI@,(?#``(3CX_^'K(`"`3J#_@?JH_Z'ZL/_!^KC_X?K`_P'[
MR/\A^]#_0?O8_V'[X/^!^^C_H?OP_\'[^/_A^Q```?@@`(!.H/^!ZJC_H>JP
M_\'JN/_AZL#_`>O(_R'KT/]!Z]C_8>O@_X'K$``!Z.C_H>NF`PA\\/_!Z_C_
MX>L@`(!.\/_!ZQ```>CX_^'KI@,(?"``@$X```!@@*(!``````"F`@A\!0"?
M0J8":'T8`$'X\/]+Z*8#"'Q08(M]%%IB?=#_##@``(OI@O``>*8#B7T(`&OI
M(`2`3LC__TO$__]+P/__2[S__TNX__]+M/__2[#__TNL__]+J/__2Z3__TN@
M__]+G/__2YC__TN4__]+D/__2XS__TN(__]+A/__2X#__TM\__]+>/__2W3_
M_TMP__]+;/__2VC__TMD__]+8/__2US__TM8__]+5/__2U#__TM,__]+2/__
M2T3__TM`__]+//__2SC__TLT__]+,/__2RS__TLH__]+)/__2R#__TL<__]+
M&/__2Q3__TL0__]+#/__2PC__TL$__]+`/__2_S^_TOX_O]+]/[_2_#^_TOL
M_O]+Z/[_2^3^_TO@_O]+W/[_2]C^_TL"`$P\5"-".*8""'P0``'XX?\A^+G(
M_TL```!@(``A.!```>BF`PA\(`"`3B]T;7``4$%27U1-4$1)4@!414U01$E2
M`%1-4`!54T52`%5315).04U%`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?
M1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO
M)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"
M`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)5
M1P!005)?1TQ/0D%,7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E
M,#)X`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N
M9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M
M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E
M<FP`4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-3``56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!E
M=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@
M,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P
M87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@
M0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A
M<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP
M6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D
M=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@
M=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR
M;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP
M+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E
M=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT
M97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!
M4CHZ0D]/5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P
M87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@
M(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S
M971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O
M<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H
M7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C
M:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I
M>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@
M*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?
M<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE
M("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS
M965K*%]&2"P@)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU
M;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R
M:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K
M/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA
M<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL
M(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,
M12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M
M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F
M:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W
M-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@
M/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@
M,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E
M;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D
M9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U
M:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O
M9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G
M9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[
M(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI
M"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A
M<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI
M9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@
M(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV
M("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M
M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]
M('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U
M<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^
M("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E
M<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*
M=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*
M)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S
M:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*
M?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q
M(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z
M($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM
M>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B([
M"F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U
M;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD
M+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D
M96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]
M?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y
M*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A
M;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N
M("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD
M9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@
M>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I
M;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S
M:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H
M("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H
M+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I
M(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO
M*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE
M*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T
M(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\
M1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M
M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E
M,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I
M+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S
M=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A
M8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@
M(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE
M("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*
M)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U
M-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP
M(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%
M3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N
M?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*
M)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB
M97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA
M;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I
M9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T
M9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@
M*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A
M<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A
M<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL
M93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK
M<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E
M9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER
M92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL
M93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W
M9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!3
M8V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z
M.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T
M=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z
M.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?
M<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U
M<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<
M7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@
M86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D
M<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN
M960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*
M)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN
M960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S
M97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE3
M5$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@
M(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,
M14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*
M;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L
M(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#
M04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L
M(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V
M86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI3
M2$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C
M='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L
M<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D
M:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*
M<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@
M)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L
M("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F
M=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_
M7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]]
M(#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.
M5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A
M<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!
M3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@```'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(````1L#.]@````:````?(?__X@$``"PC/__"`$``("-__]``0``
MX(W__V`!``"$CO__B`$``*"0___$`0``))+__P`"``#,DO__*`(``#"3__](
M`@``J)/__VP"``"(E/__D`(``*"4__^D`@``L);___0"``#HEO__"`,``$R8
M__\P`P``#)K__V`#``"8FO__@`,``.2:__^@`P``J)O__]0#``#(HO__&`0`
M`+2F__]4!```3*?__[`$``#4O/__\`0``&B]__\0!0``J+[__T@%``!<P?__
M\````!```````````7I2``1X00$;#`$`%````!@```!DP/__+`$```!!"4$`
M1P9!-````#````"@B___T`````!#"4$`09H&FP6<!)T#G@*?`1%!?D(.4$L*
M#@!"W][=W-O:!D$+```<````:````#B,__]@`````$4.<!%!?DT.`$(&00``
M`"0```"(````>(S__Z0`````10E!`)X"GP%##H`!$4%^70X`0=_>!D$X````
ML````/2,__\<`@```$,)00!!F0>:!IL%G`2=`YX"GP$107Y!#K`!`GX.`$'?
MWMW<V]K9!D$````X````[````-2.__^$`0```$,)00!!F`B9!YH&FP6<!)T#
MG@*?`1%!?D$.P`("6`X`0=_>W=S;VMG8!D$D````*`$``!R0__^H`````$0)
M00"?`4,.T`$107Y?#@!!WP9!````'````%`!``"<D/__9`````!'#B`107Y,
M#@!"!D$````@````<`$``."0__]X`````$0)00"?`40.,!%!?E(.`$'?!D$@
M````E`$``#21___@`````$<.H$$107Z?`9X";`X`0M_>!D$0````N`$``/"1
M__\8`````````$P```#,`0``])'__Q`"````10E!`!%(?T&4#)4+E@J7"9@(
MF0>:!IL%G`2=`YX"GP$107Y!#N`B`G8.`$3?WMW<V]K9V-?6U=0&009(````
M$````!P"``"TD___.``````````D````,`(``-B3__]D`0```$0)00"?`4,.
M,!%!?@).#@!!WP9!````+````%@"```4E?__P`$```!%"4$`09P$G0.>`I\!
M$4%^00ZP`0)E#@!!W][=W`9!'````(@"``"DEO__C`````!+#F`107Y,#@!$
M!D$````<````J`(``!"7__],`````$4.(!%!?D@.`$(&00```#````#(`@``
M/)?__\0`````0PE!`$&<!)T#G@*?`1%!?D$.@`%."@X`0=_>W=P&00L```!`
M````_`(``,R7__\@!P```$4)00!!EPF8")D'F@:;!9P$G0.>`I\!$4%^1P[P
M@P(#M@$.`$+?WMW<V]K9V-<&00```#@```!``P``J)[__^P#````0PE!`$&8
M")D'F@:;!9P$G0.>`I\!$4%^00ZP`0+R#@!!W][=W-O:V=@&03````!\`P``
M6*+__Y@`````10E!`)X"GP%##G`107Y3"@X`109!W]Y!"T$.`$'?W@9!```D
M````L`,``.R"__]T`@```$<.D`$107Z>`I\!`HD*#@!"W]X&00L`/````-@#
M``"4HO__B!4```!$"4$`09@(F0>:!IL%G`2=`YX"GP$107Y!#O`%`U@%#@!!
MW][=W-O:V=@&00```!P````8!```W+?__Y0`````1@X@$4%^1`X`5P9!````
M-````#@$``!0N/__0`$```!$"4$`09H&FP6<!)T#G@*?`1%!?D$.4'(*#@!!
MW][=W-O:!D$+```P````<`0``%BY__^D`0```$4)00!!FP6<!)T#G@*?`1%!
M?D$.4`):"@X`0=_>W=S;!D$+````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````__________\`
M`````````/__________```````````!``````````$``````````0``````
M``"^`@````````\`````````1`0````````,`````````+@8````````#0``
M``````"L6P```````/7^_V\`````(`(````````%`````````'`,````````
M!@````````#X`@````````H`````````8@0````````+`````````!@`````
M````%0````````````````````,`````````"/T!```````"`````````+@%
M````````%``````````'`````````!<``````````!,```````````!P````
M`)A:`````````P``<`````````````````<`````````V!`````````(````
M`````"@"````````"0`````````8`````````!@```````````````````#[
M__]O``````$```@`````^?__;P`````+````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P````#86P````````-<````
M``````````````#=6P```````-U<````````Z%L```````#O7````````/!;
M``````````````````#T6P```````/E;``````````````````"17@``````
M`$=#0SH@*$%L<&EN92`Y+C,N,"D@.2XS+C```"YS:'-T<G1A8@`N:6YT97)P
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YC=&]R<P`N9'1O<G,`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M```````````````````````````````````````````+`````0````(`````
M``````(``````````@```````!X````````````````````!````````````
M````````$P```/;__V\"`````````"`"````````(`(```````#8````````
M``,`````````"````````````````````!T````+`````@````````#X`@``
M`````/@"````````>`D````````$`````P````@`````````&``````````E
M`````P````(`````````<`P```````!P#````````&($````````````````
M```!````````````````````+0````0````"`````````-@0````````V!``
M```````H`@````````,`````````"``````````8`````````#<````$````
M0@``````````$P`````````3````````N`4````````#````$`````@`````
M````&`````````!!`````0````8`````````N!@```````"X&````````#0`
M```````````````````$````````````````````1P````$````&````````
M```9`````````!D```````"L0@``````````````````(```````````````
M`````$T````!````!@````````"L6P```````*Q;````````+```````````
M``````````0```````````````````!3`````0````(`````````V%L`````
M``#86P```````$P]```````````````````(````````````````````6P``
M``$````"`````````"29````````))D```````#<````````````````````
M!````````````````````&D````!`````@``````````F@````````":````
M````I`0```````````````````0```````````````````!S`````0````,`
M````````*/L!```````H^P```````!`````````````````````(````````
M````````````>@````$````#`````````#C[`0``````./L````````0````
M````````````````"````````````````````($````&`````P````````!(
M^P$``````$C[````````P`$````````$``````````@`````````$```````
M```\````"`````,`````````"/T!```````(_0```````/@!````````````
M```````(``````````@`````````B@````$````#``````````#_`0``````
M`/\```````!H``````````````````````$````````(`````````(\````!
M`````P````````````(``````````0``````>`````````````````````@`
M``````````````````"5````"`````,`````````>``"``````!X``$`````
M`&@0```````````````````(````````````````````F@````$````P````
M````````````````>``!```````:`````````````````````0`````````!
M``````````$````#`````````````````````````)(``0``````HP``````
:``````````````$`````````````````````
